HookFn

Type Alias HookFn 

pub type HookFn = Arc<dyn Fn(&HookContext, &SerializedTask) -> Pin<Box<dyn Future<Output = Result<()>> + Send>> + Send + Sync>;
Type alias for async lifecycle hook functions

Hooks are async functions that take a hook context and serialized task, and return a Result. They can be used to inject custom logic at various points in the task lifecycle.

Aliased Type

pub struct HookFn { /* private fields */ }